#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module Spendcontrols
			class Card < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'100b2b84-4ee1-4e22-9927-7baad788eb36' => OperationConfig.new("/issuer/spendcontrols/v1/card", "create", [], []),
					'0d453728-973c-486b-86d9-0b08386725ba' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}", "read", [], []),
					'7b2f5fb5-3b8c-4dcb-b18f-108e0953e090' => OperationConfig.new("/issuer/spendcontrols/v1/card/uuid", "create", [], []),
					'2ee8dec7-7a7e-4533-aa73-80d716f8aaba' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}", "delete", [], []),
					'92dccd41-bec2-45ee-a449-93d0230796b8' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}", "create", [], []),
					
				}

				protected

				def self.getOperationConfig(operationUUID)
					if @__store.key?(operationUUID)
						return @__store[operationUUID]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
				end

				public


				def self.create(mapObj)
					#
					#Creates object of type Card
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Card] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("100b2b84-4ee1-4e22-9927-7baad788eb36", Card.new(mapObj))
				end











				def self.retrievePan(id, criteria = nil)
					#
					#Returns objects of type Card by id and optional criteria
					#@param [String] id
					#@param [Dict] criteria
					#@return [Card] object representing the response
					#@raise [APIException] an exception from the response status

					mapObj = Card.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !criteria.nil?
						if criteria.instance_of? RequestMap
						  mapObj.setAll(criteria.getObject())
						else
						  mapObj.setAll(criteria)
						end
					end

					return self.execute("0d453728-973c-486b-86d9-0b08386725ba",Card.new(mapObj))
				end



				def self.read(mapObj)
					#
					#Creates object of type Card
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Card] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("7b2f5fb5-3b8c-4dcb-b18f-108e0953e090", Card.new(mapObj))
				end










				def self.deleteById(id, map = nil)
					#Delete object of type Card by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Card] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Card.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("2ee8dec7-7a7e-4533-aa73-80d716f8aaba", mapObj)
				end


				def delete
					#
					#Delete object of type Card

					#@param [String] id
					#@return [Card] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("2ee8dec7-7a7e-4533-aa73-80d716f8aaba", self)
				end




				def self.update(mapObj)
					#
					#Creates object of type Card
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Card] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("92dccd41-bec2-45ee-a449-93d0230796b8", Card.new(mapObj))
				end







			end
		end
	end
end







