#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module Spendcontrols
			class Channel < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'd06f1b1a-a494-4d55-bdbe-26cfbc803108' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "delete", [], []),
					'23f7599a-3a5d-4dbc-b9f4-698501d3e958' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "query", [], []),
					'9339799c-f25d-4da6-b138-bfcccde6a521' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/channels", "create", [], []),
					
				}

				protected

				def self.getOperationConfig(operationUUID)
					if @__store.key?(operationUUID)
						return @__store[operationUUID]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
				end

				public





				def self.deleteById(id, map = nil)
					#Delete object of type Channel by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Channel] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Channel.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("d06f1b1a-a494-4d55-bdbe-26cfbc803108", mapObj)
				end


				def delete
					#
					#Delete object of type Channel

					#@param [String] id
					#@return [Channel] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("d06f1b1a-a494-4d55-bdbe-26cfbc803108", self)
				end









				def self.query(criteria)
					#
					#Query objects of type Channel by id and optional criteria
					#@param [Dict] criteria
					#@return [Channel] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("23f7599a-3a5d-4dbc-b9f4-698501d3e958",Channel.new(criteria))
				end


				def self.create(mapObj)
					#
					#Creates object of type Channel
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Channel] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("9339799c-f25d-4da6-b138-bfcccde6a521", Channel.new(mapObj))
				end







			end
		end
	end
end







