#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module Spendcontrols
			class Controls < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'c79b0b52-cd2e-4812-b82f-3213545f77b9' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls", "delete", [], []),
					'0cd0293d-1bda-4b42-9dcb-946fc0a2d507' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls", "query", [], []),
					'cdf0aaeb-133c-48bb-b739-93a6238076cd' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls", "create", [], []),
					
				}

				protected

				def self.getOperationConfig(operationUUID)
					if @__store.key?(operationUUID)
						return @__store[operationUUID]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
				end

				public





				def self.deleteById(id, map = nil)
					#Delete object of type Controls by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Controls] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Controls.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("c79b0b52-cd2e-4812-b82f-3213545f77b9", mapObj)
				end


				def delete
					#
					#Delete object of type Controls

					#@param [String] id
					#@return [Controls] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("c79b0b52-cd2e-4812-b82f-3213545f77b9", self)
				end









				def self.query(criteria)
					#
					#Query objects of type Controls by id and optional criteria
					#@param [Dict] criteria
					#@return [Controls] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("0cd0293d-1bda-4b42-9dcb-946fc0a2d507",Controls.new(criteria))
				end


				def self.create(mapObj)
					#
					#Creates object of type Controls
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Controls] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("cdf0aaeb-133c-48bb-b739-93a6238076cd", Controls.new(mapObj))
				end







			end
		end
	end
end







