#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module Spendcontrols
			class Crossborder < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'79905300-f1cc-4bf0-a458-d1346bd3c72b' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "delete", [], []),
					'ded96ff0-49eb-4bc8-b1d0-b481d2f8d28b' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "query", [], []),
					'ae3a4d57-5ade-49cc-9a8e-473d20c1a742' => OperationConfig.new("/issuer/spendcontrols/v1/card/{uuid}/controls/alerts/crossborder", "create", [], []),
					
				}

				protected

				def self.getOperationConfig(operationUUID)
					if @__store.key?(operationUUID)
						return @__store[operationUUID]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
				end

				public





				def self.deleteById(id, map = nil)
					#Delete object of type Crossborder by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [Crossborder] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = Crossborder.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("79905300-f1cc-4bf0-a458-d1346bd3c72b", mapObj)
				end


				def delete
					#
					#Delete object of type Crossborder

					#@param [String] id
					#@return [Crossborder] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("79905300-f1cc-4bf0-a458-d1346bd3c72b", self)
				end









				def self.query(criteria)
					#
					#Query objects of type Crossborder by id and optional criteria
					#@param [Dict] criteria
					#@return [Crossborder] object representing the response.
					#@raise [APIException] an exception from the response status
					#

					return self.execute("ded96ff0-49eb-4bc8-b1d0-b481d2f8d28b",Crossborder.new(criteria))
				end


				def self.create(mapObj)
					#
					#Creates object of type Crossborder
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [Crossborder] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("ae3a4d57-5ade-49cc-9a8e-473d20c1a742", Crossborder.new(mapObj))
				end







			end
		end
	end
end







